PCB Environment: Class Hierarchy

PCB Environment 2

Loading...
Searching...
No Matches
Class Hierarchy
This inheritance list is sorted roughly, but not completely, alphabetically:
[detail level 12]

C Action | NOTE: Actions always set the Agent's least recently used connction (getConnectionLRU()) which is somewhat ugly for actions affecting multiple connections - we should probably return a set of affected connections if we ever have actions that change more than one (other than clustering which doesn't really change anything)
C ActionCache< Data > |
C ActionSet |
C ActionSpace |
C Agent |
C RRRAgent |
C UserAgent |
C AlignedTHPAllocator< T > |
C AShape |
C CircleEx |
C IsoRectEx |
C PolygonEx |
C TriangleEx |
C WideSegment_25 |
C AStar |
C AStarCosts |
C AStarVisitStatus |
C BaseROP |
C RecordRangesROP |
C dsn::BBox |
C py::BorrowedRef |
C Camera |
CCircle_2 |
C CircleEx |
C CloneEnv |
C Color |
C Policy::CommonParams |
C Connection |
C dsn::Connection |
C dsn::Data |
C py::DictIterator |
C DRCViolation |
C DSNParserBase |
C Env |
C EnvPCB |
C fancy_lock_guard |
C py::GIL_guard | The GIL
C GridDirection |
C IBox_3 |
C dsn::Image |
C IndexRange |
C PCBoardMesh::IndexRange |
C IPoint_2 |
C IPoint_3 |
CIso_rectangle_2 |
C IsoRectEx |
C IUIApplication |
C UIApplication |
C IVector_2 |
C IVector_3 |
C dsn::Layer |
C Layer |
C LayoutArea |
C Length< T, M1, Q1 > |
C LogFile |
C Logger |
C LubySequence |
C math::Mat4 |
C math::Moments |
C ui::NavGrid |
C NavKeepoutCounts |
C NavMesh |
C NavPixel< chan_t > |
C NavPoint |
C NavPointRef |
C NavRasterizeParams |
C NavSpacings | This struct stores the spacing requirements the NavGrid is/should be prepared for
C NavTri | Data associated with a triangle in the Delaunay triangulation of the board
C NavTriangulation | Interface to the Delaunay triangulation
C dsn::Net |
C Net |
C NetOverrides |
C NetTopology |
C py::NPArray< T > |
C Object |
C Component |
C Pin |
C py::Object | NOTE: This does not do any automatic reference counting
C ObjectPtrNameLessThan |
C py::ObjectRef |
C ObjectsBVH |
C dsn::Padstack |
C Palette |
C Parameter |
C dsn::Path |
C Path |
C dsn::PCB |
C PCBFactory |
C PCBItemSets |
C PCBoard |
C PCBoardMesh |
C dsn::Pin |
C dsn::Placement |
C Point_25 |
C Policy |
CPolygon_2 |
C PolygonEx |
C Pusher |
CQHBoxLayout |
C LayerAlphaSlider |
CQOpenGLFunctions_4_3_Core |
C GLWidget |
CQOpenGLWidget |
C GLWidget |
CQWidget |
C ActionTab |
C BrowserTab |
C ParameterTab |
C ViewTab |
C Window |
C Rasterizer< ROP > |
C RatsNest |
C Action::Result |
C ResultCollection |
C ResultRecord |
C RewardFunction |
C rewards::RouteLength |
C RoutePainter |
C RoutePainterLines |
C RouterResult |
C RouteTracker |
C dsn::Segment |
C Segment_25 |
C Shaders |
C dsn::Shape |
C SignalContext |
C StateRepresentation | The subclass create(PyObject *) functions check if the PyObject matches and return a new instace if it does, or 0 otherwise (or throw an exception if the name matches but the parameters don't)
C StepLock |
C dsn::Structure |
C Token |
C dsn::Track |
C Track |
CTriangle_2 |
C TriangleEx |
C TriList |
C UIActions | WARNING: The non-async UIActions functions are expected to be non-concurrent
C UniformGrid25 |
C NavGrid | The grid-representation of the board
C NavImage< chan_t > |
C UserSettings |
C dsn::Via |
C Via |
C ViaPainter |